<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu">
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation>új</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrawMapWidget</name>
    <message>
        <source>File error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot open file &apos;%1&apos; for writing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot read file &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation>Soha</translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation>
            <numerusform>Minden %1 körben</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Edit weapons</source>
        <translation>Fegyverek beállítása</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>Illegal ammo scheme</source>
        <translation>Szabálytalan lőszerséma</translation>
    </message>
    <message>
        <source>Edit schemes</source>
        <translation>Sémák szerkesztése</translation>
    </message>
    <message>
        <source>When this option is enabled selecting a game scheme will auto-select a weapon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Options</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 *** %2 has been removed from your ignore list</source>
        <translation type="obsolete">%1 *** %2 eltávolítva a figyelmen kívül hagyottak listájáról</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your ignore list</source>
        <translation type="obsolete">%1 *** %2 hozzáadva a figyelmen kívül hagyottak listájához</translation>
    </message>
    <message>
        <source>%1 *** %2 has been removed from your friends list</source>
        <translation type="obsolete">%1 *** %2 eltávolítva a barátlistáról</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your friends list</source>
        <translation type="obsolete">%1 *** %2 hozzáadva a barátlistádhoz</translation>
    </message>
    <message>
        <source>%1 has been removed from your ignore list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 has been added to your ignore list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 has been removed from your friends list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 has been added to your friends list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stylesheet imported from %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter %1 if you want to use the current StyleSheet in future, enter %2 to reset!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t read %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>StyleSheet discarded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>StyleSheet saved to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save StyleSheet to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is not a valid command!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kicking %1 ...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>new</source>
        <translation type="obsolete">új</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Unable to start the server</source>
        <translation>A szervert nem sikerült elindítani</translation>
    </message>
    <message>
        <source>Cannot save record to file %1</source>
        <translation>Nem sikerült menteni a %1 fájlba</translation>
    </message>
    <message>
        <source>Please select record from the list above</source>
        <translation>Kérlek válassz a fentebbi listából</translation>
    </message>
    <message>
        <source>DefaultTeam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars Demo File</source>
        <comment>File Types</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars Save File</source>
        <comment>File Types</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Demo name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Demo name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game aborted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished">JElszó</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password below
or pick another nickname in game config:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No password supplied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished">Becenév</translation>
    </message>
    <message>
        <source>Some one already uses
 your nickname %1
on the server.
Please pick another nickname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No nickname supplied.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation>hu.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation>Nem sikerült megnyitni a %1 demót</translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>Map</source>
        <translation>Pálya</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Témák</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Szűrő</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Minden</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Kicsi</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Közepes</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Nagy</translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation>Barlang</translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation>Őrült</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation>Szűk alagutak</translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation>Átlagos alagutak</translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation>Tágas alagutak</translation>
    </message>
    <message>
        <source>Small floating islands</source>
        <translation>Apró lebegő szigetek</translation>
    </message>
    <message>
        <source>Medium floating islands</source>
        <translation>Közepes lebegő szigetek</translation>
    </message>
    <message>
        <source>Large floating islands</source>
        <translation>Nagy lebegő szigetek</translation>
    </message>
    <message>
        <source>Seed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation>Host nem található. Kérlek, ellenőrizd a host név és port beállításokat.</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>Kapcsolat visszautasítva</translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation>Szoba megszűnt</translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation>Kilépés oka:</translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation>Kirúgtak</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">JElszó</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password
or pick another nickname:</source>
        <translation type="obsolete">A %1 név már
regisztrálva van a Hedgewars.org-on
Írd be a jelszavad
vagy válassz másik nevet:</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation>%1 *** %2 belépett a szobába</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined</source>
        <translation>%1 *** %2 csatlakozott</translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation>%1 *** %2 távozott (%3)</translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation>%1 *** %2 távozott</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="obsolete">Becenév</translation>
    </message>
    <message>
        <source>User quit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KB</name>
    <message>
        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
        <translation>SDL_ttf hibát dobott a szöveg kiírásakor, ezt valószínűleg a freetype2 egy hibája okozza. Ajánlott a freetype lib frissítése.</translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Server message:</source>
        <translation type="obsolete">Server message:</translation>
    </message>
    <message>
        <source>Set message</source>
        <translation type="obsolete">Set message</translation>
    </message>
    <message>
        <source>Clear Accounts Cache</source>
        <translation>Accounts Cache kiürítése</translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation>Adatszerzés</translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation>Szerverüzenet a legújabb verzióhoz:</translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation>Szerver üzenete az előző verzióknak:</translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation>Legújabb verzió protokollszáma:</translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation>MOTD előnézet:</translation>
    </message>
    <message>
        <source>Set data</source>
        <translation>Adat beállítása</translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation>Csatlakozás...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Mégse</translation>
    </message>
</context>
<context>
    <name>PageDrawMap</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished">Törlés</translation>
    </message>
    <message>
        <source>Load</source>
        <translation type="unfinished">Betöltés</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load drawn map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save drawn map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drawn Maps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation>Általános</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Haladó</translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;A legjobb lövés díját &lt;b&gt;%1&lt;/b&gt; nyerte &lt;b&gt;%2&lt;/b&gt; ponttal.&lt;/p&gt;</translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;A legjobb gyilkos &lt;b&gt;%1&lt;/b&gt; volt, &lt;b&gt;%2&lt;/b&gt; áldozattal egy körben.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;Összesen &lt;b&gt;%1&lt;/b&gt; süni pusztult el ebben a játékban.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Health graph</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ranking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%1 kill)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; thought it&apos;s good to shoot his own hedgehogs with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; killed &lt;b&gt;%2&lt;/b&gt; of his own hedgehogs.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; was scared and skipped turn &lt;b&gt;%2&lt;/b&gt; times.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageInGame</name>
    <message>
        <source>In game...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Local Game (Play a game on a single computer)</source>
        <translation>Helyi játék (Játssz egyetlen számítógépen)</translation>
    </message>
    <message>
        <source>Network Game (Play a game across a network)</source>
        <translation>Hálózati játék (Játék hálózaton keresztül)</translation>
    </message>
    <message>
        <source>Simply pick the same color as a friend to play together as a team. Each of you will still control his or her own hedgehogs but they&apos;ll win or lose together.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Some weapons might do only low damage but they can be a lot more devastating in the right situation. Try to use the Desert Eagle to knock multiple hedgehogs into the water.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you&apos;re unsure what to do and don&apos;t want to waste ammo, skip one round. But don&apos;t let too much time pass as there will be Sudden Death!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you&apos;d like to keep others from using your preferred nickname on the official server, register an account at http://www.hedgewars.org/.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You&apos;re bored of default gameplay? Try one of the missions - they&apos;ll offer different gameplay depending on the one you picked.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By default the game will always record the last game played as a demo. Select &apos;Local Game&apos; and pick the &apos;Demos&apos; button on the lower right corner to play or manage them.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you&apos;ve got problems, ask on our forums but please don&apos;t expect 24/7 support!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you like it, help us with a small donation or contribute your own work!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. Share it with your family and friends as you like!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If someone sold you the game, you should try get a refund!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>From time to time there will be official tournaments. Upcoming events will be announced at http://www.hedgewars.org/ some days in advance.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars is available in many languages. If the translation in your language seems to be missing or outdated, feel free to contact us!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars can be run on lots of different operating systems including Microsoft Windows, Mac OS X and Linux.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always remember you&apos;re able to set up your own games in local and network/online play. You&apos;re not restricted to the &apos;Simple Game&apos; option.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connect one or more gamepads before starting the game to be able to assign their controls to your teams.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create an account on %1 to keep others from using your most favourite nickname while playing on the official server.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>While playing you should give yourself a short break at least once an hour.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to enable the low quality mode to improve performance.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to update the associated drivers.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>We&apos;re open to suggestions and constructive feedback. If you don&apos;t like something or got a great idea, let us know!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Especially while playing online be polite and always remember there might be some minors playing with or against you as well!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Special game modes such as &apos;Vampirism&apos; or &apos;Karma&apos; allow you to develop completely new tactics. Try them in a custom game!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You should never install Hedgewars on computers you don&apos;t own (school, university, work, etc.). Please ask the responsible person instead!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars can be perfect for short games during breaks. Just ensure you don&apos;t add too many hedgehogs or use an huge map. Reducing time and health might help as well.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No hedgehogs were harmed in making this game.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There are three different jumps available. Tap [high jump] twice to do a very high/backwards jump.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Afraid of falling off a cliff? Hold down [precise] to turn [left] or [right] without actually moving.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Some weapons require special strategies or just lots of training, so don&apos;t give up on a particular tool if you miss an enemy once.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Most weapons won&apos;t work once they touch the water. The Homing Bee as well as the Cake are exceptions to this.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Old Limbuger only causes a small explosion. However the wind affected smelly cloud can poison lots of hogs at once.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Piano Strike is the most damaging air strike. You&apos;ll lose the hedgehog performing it, so there&apos;s a huge downside as well.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sticky Mines are a perfect tool to create small chain reactions knocking enemy hedgehogs into dire situations ... or water.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Hammer is most effective when used on bridges or girders. Hit hogs will just break through the ground.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you&apos;re stuck behind an enemy hedgehog, use the Hammer to free yourself without getting damaged by an explosion.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Cake&apos;s maximum walking distance depends on the ground it has to pass. Use [attack] to detonate it early.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Flame Thrower is a weapon but it can be used for tunnel digging as well.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Want to know who&apos;s behind the game? Click on the Hedgewars logo in the main menu to see the credits.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Like Hedgewars? Become a fan on %1 or follow us on %2!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Feel free to draw your own graves, hats, flags or even maps and themes! But note that you&apos;ll have to share them somewhere to use them online.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Really want to wear a specific hat? Donate to us and receive an exclusive hat of your choice!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keep your video card drivers up to date to avoid issues playing the game.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;My Documents\Hedgewars&quot;. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You&apos;re able to associate Hedgewars related files (savegames and demo recordings) with the game to launch them right from your favorite file or internet browser.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Want to save ropes? Release the rope in mid air and then shoot again. As long as you don&apos;t touch the ground you&apos;ll reuse your rope without wasting ammo!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;Library/Application Support/Hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;.hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Windows version of Hedgewars supports Xfire. Make sure to add Hedgewars to its game list so your friends can see you playing.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the Molotov or Flame Thrower to temporary keep hedgehogs from passing terrain such as tunnels or platforms.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Homing Bee can be tricky to use. Its turn radius depends on its velocity, so try to not use full power.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloadable Content</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
</context>
<context>
    <name>PageNet</name>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>Please select server from the list above</source>
        <translation>Kérlek, válassz szervert a fenti listából</translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Control</source>
        <translation>Irányítás</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Hiba</translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation type="unfinished">Add meg a szoba nevét</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
</context>
<context>
    <name>PageNetType</name>
    <message>
        <source>LAN game</source>
        <translation>LAN játék</translation>
    </message>
    <message>
        <source>Official server</source>
        <translation>Hivatalos szerver</translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation>Új csapat</translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation>Csapat szerkesztése</translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation>Csapat törlése</translation>
    </message>
    <message>
        <source>New weapon scheme</source>
        <translation type="obsolete">Új fegyverséma</translation>
    </message>
    <message>
        <source>Edit weapon scheme</source>
        <translation type="obsolete">Fegyverséma szerkesztése</translation>
    </message>
    <message>
        <source>Delete weapon scheme</source>
        <translation type="obsolete">Fegyverséma törlése</translation>
    </message>
    <message>
        <source>You can&apos;t edit teams from team selection. Go back to main menu to add, edit or delete teams.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New weapon set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit weapon set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete weapon set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Rename dialog</source>
        <translation>Párbeszéd átnevezése</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>Add meg az új fájl nevét:</translation>
    </message>
    <message>
        <source>Cannot rename to</source>
        <translation>Nem nevezhető át erre -</translation>
    </message>
    <message>
        <source>Cannot delete file</source>
        <translation>Fájl nem törölhető</translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation>Kérlek, válassz a listából</translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Create</source>
        <translation>Létrehozás</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Csatlakozás</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Frissítés</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Admin features</source>
        <translation>Adminisztráció</translation>
    </message>
    <message>
        <source>Room Name:</source>
        <translation>Szoba neve:</translation>
    </message>
    <message>
        <source>This game is in lobby.
You may join and start playing once the game starts.</source>
        <translation>Ez a játék elérhető.
Csatlakozz és játssz, amikor a játék elkezdődik.</translation>
    </message>
    <message>
        <source>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
        <translation>Ez a játék folyamatban van.
Csatlakozhatsz mint megfigyelő, de a játszáshoz meg kell várnod a jelenlegi meccs befejeződését.</translation>
    </message>
    <message>
        <source>%1 is the host. He may adjust settings and start the game.</source>
        <translation>%1 a host. Ő kezeli a beállításokat és a játék indítását.</translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation>Véletlen pálya</translation>
    </message>
    <message>
        <source>Games may be played on precreated or randomized maps.</source>
        <translation>A játékok előkészített vagy véletlen pályákon játszódnak.</translation>
    </message>
    <message>
        <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
        <translation>A játék sémája az általános beállításokat határozza meg. illetve egyéb dolgokat, mint egy kör ideje, Hirtelen halál vagy Vámpírizmus.</translation>
    </message>
    <message>
        <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
        <translation>A fegyverséma az elérhető fegyverek és a lőszer mennyiségét határozza meg.</translation>
    </message>
    <message numerus="yes">
        <source>There are %1 clients connected to this room.</source>
        <translation>
            <numerusform>Összesen %1 kliens csatlakozott a szobához.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>There are %1 teams participating in this room.</source>
        <translation>
            <numerusform>Összesen %1 csapat van a szobában.</numerusform>
        </translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation>Add meg a szoba nevét</translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation>Válassz egy szobát a listából</translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation>Véletlen labirintus</translation>
    </message>
    <message>
        <source>Rules:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weapons:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished">Törlés</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The game you are trying to join has started.
Do you still want to join the room?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%1 players online</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation>Védd meg az erődöd, és pusztítsd el az ellenfelekét! Legfeljebb két csapatszín!</translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation>A csapatok a pálya két végén kezdenek. Legfeljebb két csapatszín!</translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation>A talajt nem lehet elpusztítani!</translation>
    </message>
    <message>
        <source>Add an indestructable border around the terrain</source>
        <translation type="obsolete">A pálya köré egy elpusztíthatatlan keret felhúzása</translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation>Gyengébb gravitáció</translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation>A célzás segítése egy lézerkövetővel</translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation>Minden süninek saját erőtere van</translation>
    </message>
    <message>
        <source>Enable random mines</source>
        <translation type="obsolete">Véletlen aknaidőzítés engedélyezése</translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation>Az általad okozott sebzés 80% -át visszagyógyulod</translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation>Megosztod ellenfeled fájdalmát, ahogy a sérülésüket is</translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation>A sünik nem tudnak mozogni, próbára téve a célzóképességed</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Véletlen</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>másodperc</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Új</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation>A lépéssorrend véletlen a következőségi sorrend helyett.</translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation>Kapsz egy királyt. Ha meghal, a te oldalad veszít.</translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation>Felváltva helyezitek el a sünöket a játék kezdete előtt.</translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation>A lőszerek közösek az azonos színű csapatok között.</translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation>Hidak letiltása véletlen pályák létrehozásakor.</translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation>Tereptárgyak letiltása véletlen pálya létrehozásakor.</translation>
    </message>
    <message>
        <source>All (living) hedgehogs are fully restored at the end of turn</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AI respawns on death.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Attacking does not end your turn.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weapons are reset to starting values each turn.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Each hedgehog has its own ammo. It does not share with the team.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You will not have to worry about wind anymore.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wind will affect almost everything.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Teams in each clan take successive turns sharing their turn time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add an indestructible border around the terrain</source>
        <translation>A pálya köré egy elpusztíthatatlan keret felhúzása</translation>
    </message>
    <message>
        <source>Add an indestructible border along the bottom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation>Default</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished">Új</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
        <translation>Egyszerű játék (gyors játék a gép ellen, a beállításokat már kiválasztottuk neked)</translation>
    </message>
    <message>
        <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
        <translation>Többjátékos (hotseat játék a barátaid vagy a gép csapatai ellen)</translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
        <translation type="obsolete">Gyakorlás (fejleszd magad a gyakorlóküldetéseken keresztül). FEJLESZTÉS ALATT</translation>
    </message>
    <message>
        <source>Demos (Watch recorded demos)</source>
        <translation>Demók (felvett demók megtekintése)</translation>
    </message>
    <message>
        <source>Load (Load a previously saved game)</source>
        <translation>Betöltés (korábbi mentett állás visszatöltése)</translation>
    </message>
    <message>
        <source>Campaign Mode (...)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageTraining</name>
    <message>
        <source>No description available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a mission!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation>Kirúgás</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation>Csatlakozások korlátozása</translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation>Csapatok hozzáadásának korlátozása</translation>
    </message>
    <message>
        <source>Ban</source>
        <translation>Bannolás</translation>
    </message>
    <message>
        <source>Follow</source>
        <translation>Követés</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorálás</translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation>Barát felvétele</translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation>Ignorálás feloldása</translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation>Barát eltávolítása</translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="unfinished">Frissítés</translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Check for updates at startup</source>
        <translation>Frissítések keresése induláskor</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Teljes képernyő</translation>
    </message>
    <message>
        <source>Frontend fullscreen</source>
        <translation>Frontend teljesképernyő</translation>
    </message>
    <message>
        <source>Enable sound</source>
        <translation>Hangok engedélyezése</translation>
    </message>
    <message>
        <source>Enable music</source>
        <translation>Zene engedélyezése</translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation>FPS megjelenítése</translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation>Alternatív sebzés mutatása</translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation>Dátum és idő hozzáadása a tároló fájl nevéhez</translation>
    </message>
    <message>
        <source>Reduced quality</source>
        <translation type="obsolete">Csökkentett minőség</translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation>Lőszer menü tippjeinek mutatása</translation>
    </message>
    <message>
        <source>Enable frontend sounds</source>
        <translation>Frontend hangok engedélyezése</translation>
    </message>
    <message>
        <source>Enable frontend music</source>
        <translation>Frontend zenéjének engedélyezése</translation>
    </message>
    <message>
        <source>Frontend effects</source>
        <translation>Frontend effektusok</translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>generated map...</source>
        <translation>a létrehozott pálya...</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>Ember</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Szint</translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation>(rendszer default)</translation>
    </message>
    <message>
        <source>Mission</source>
        <translation>Küldetés</translation>
    </message>
    <message>
        <source>generated maze...</source>
        <translation>a létrehozott labirintus...</translation>
    </message>
    <message>
        <source>Community</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Any</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In lobby</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">Default</translation>
    </message>
    <message>
        <source>hand drawn map...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Cyan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cyan/Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue/Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green/Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Side-by-side</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top-Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wiggle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Cyan grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cyan/Red grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Blue grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue/Red grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Green grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green/Red grayscale</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Team Members</source>
        <translation>Csapattagok</translation>
    </message>
    <message>
        <source>Fort</source>
        <translation>Erőd</translation>
    </message>
    <message>
        <source>Key binds</source>
        <translation>Billentyűzet testreszabása</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Csapatok</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="obsolete">Fegyverek</translation>
    </message>
    <message>
        <source>Audio/Graphic options</source>
        <translation>Hang- és képi beállítások</translation>
    </message>
    <message>
        <source>Net game</source>
        <translation>Netes játék</translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation>Résztvevő csapatok</translation>
    </message>
    <message>
        <source>Game Modifiers</source>
        <translation>Játék módosítók</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>Alap beállítások</translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation>Csapat beállítások</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Egyéb</translation>
    </message>
    <message>
        <source>Schemes and Weapons</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Mines Time</source>
        <translation>Aknák ideje</translation>
    </message>
    <message>
        <source>Mines</source>
        <translation>Aknák</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verzió</translation>
    </message>
    <message>
        <source>This program is distributed under the GNU General Public License</source>
        <translation type="obsolete">Ez a program a GNU General Public License alatt terjesztett</translation>
    </message>
    <message>
        <source>Developers:</source>
        <translation>Fejlesztők:</translation>
    </message>
    <message>
        <source>Art:</source>
        <translation>Grafika:</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation>Hangok:</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>Fordítások:</translation>
    </message>
    <message>
        <source>Special thanks:</source>
        <translation>Külön köszönet:</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Fegyverek</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Net nick</source>
        <translation>Becenév a neten</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Felbontás</translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation>FPS határ</translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation>Szerver név:</translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation>Szerver port:</translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation>Kezdeti hangerő</translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation>Sebzés módosító</translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation>Köridő</translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation>Kezdeti életerő</translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation>Hirtelen halál kezdete</translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation>Séma neve:</translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation>Csomagok érkezése</translation>
    </message>
    <message>
        <source>Game scheme</source>
        <translation>Játék sémája</translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation>% hamis aknák</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Típus</translation>
    </message>
    <message>
        <source>Grave</source>
        <translation>Sírkő</translation>
    </message>
    <message>
        <source>Flag</source>
        <translation>Zászló</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Hang</translation>
    </message>
    <message>
        <source>Locale</source>
        <translation>Nyelv</translation>
    </message>
    <message>
        <source>Restart game to apply</source>
        <translation>Újraindításkor lép érvénybe</translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation>Robbanótöltetek</translation>
    </message>
    <message>
        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
Some features might be broken or incomplete. Use at your own risk!</source>
        <translation type="obsolete">Ez az SVN build még fejlesztés alatt áll és esetlegesen nem kompatibilis a játék más verzióival.
Néhány részlet esetleg nem működik vagy nincs készen. Csak saját felelősségre használd!</translation>
    </message>
    <message>
        <source>Tip: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This development build is &apos;work in progress&apos; and may not be compatible with other versions of the game. Some features might be broken or incomplete. Use at your own risk!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>% Health Crates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Health in Crates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sudden Death Water Rise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sudden Death Health Decrease</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>% Rope Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stereo rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished">JElszó</translation>
    </message>
    <message>
        <source>% Get Away Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This program is distributed under the GNU General Public License v2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation>névtelen</translation>
    </message>
    <message>
        <source>hedgehog %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation>Hedgewars %1</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Network</source>
        <translation>Hálózat</translation>
    </message>
    <message>
        <source>Connection to server is lost</source>
        <translation>A kapcsolat a szerverrel megszakadt</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1
Please check your installation</source>
        <translation>Nem sikerült megnyitni az alábbi könyvtárat:
 %1
Kérlek, ellenőrizd a telepítésed</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Fegyverek</translation>
    </message>
    <message>
        <source>Can not edit default weapon set</source>
        <translation type="obsolete">Az alap fegverkészlet nem szerkeszthető</translation>
    </message>
    <message>
        <source>Can not delete default weapon set</source>
        <translation type="obsolete">Az alap fegyverkeszléet nem törölhető</translation>
    </message>
    <message>
        <source>Really delete this weapon set?</source>
        <translation>Valóban törlöd ezt a fegyverkészletet?</translation>
    </message>
    <message>
        <source>All file associations have been set.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File association failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not overwrite default weapon set &apos;%1&apos;!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Teams</source>
        <translation type="unfinished">Csapatok</translation>
    </message>
    <message>
        <source>Really delete this team?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Schemes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not delete default scheme &apos;%1&apos;!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Really delete this game scheme?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not delete default weapon set &apos;%1&apos;!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>Nem sikerült létrehozni %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Becenév</translation>
    </message>
    <message>
        <source>Please enter your nickname</source>
        <translation>Add meg a beceneved</translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>default</source>
        <translation>default</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
    <message>
        <source>Start server</source>
        <translation>Szerver indítása</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Kapcsolódás</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Frissítés</translation>
    </message>
    <message>
        <source>Specify</source>
        <translation>Specifikálás</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Go!</source>
        <translation>Mehet!</translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation>Demo lejátszása</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Átnevezés</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Betöltés</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Beállítás</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Kész</translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation>Véletlen csapat</translation>
    </message>
    <message>
        <source>Associate file extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>more</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QTableWidget</name>
    <message>
        <source>Room Name</source>
        <translation>Szoba neve</translation>
    </message>
    <message>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <source>Owner</source>
        <translation>Tulajdonos</translation>
    </message>
    <message>
        <source>Map</source>
        <translation>Pálya</translation>
    </message>
    <message>
        <source>Rules</source>
        <translation>Szabályok</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Fegyverek</translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation>Fegyverkészlet</translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation>Valószínűségek</translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation>Lőszer a dobozokban</translation>
    </message>
    <message>
        <source>Delays</source>
        <translation>Késleltetések</translation>
    </message>
    <message>
        <source>new</source>
        <translation type="unfinished">új</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>Unable to start the server: %1.</source>
        <translation>Nem sikerült a szerverhez csatlakozni: %1.</translation>
    </message>
    <message>
        <source>Unable to run engine: %1 (</source>
        <translation>Nem sikerült a játékot futtatni: %1 (</translation>
    </message>
</context>
<context>
    <name>ToggleButtonWidget</name>
    <message>
        <source>Vampirism</source>
        <translation>Vámpírizmus</translation>
    </message>
    <message>
        <source>Karma</source>
        <translation>Karma</translation>
    </message>
    <message>
        <source>Artillery</source>
        <translation>Tüzérség</translation>
    </message>
    <message>
        <source>Fort Mode</source>
        <translation>Erődítmény</translation>
    </message>
    <message>
        <source>Divide Teams</source>
        <translation>Csapatok felosztása</translation>
    </message>
    <message>
        <source>Solid Land</source>
        <translation>Szilárd talaj</translation>
    </message>
    <message>
        <source>Add Border</source>
        <translation>Határok felállítása</translation>
    </message>
    <message>
        <source>Low Gravity</source>
        <translation>Alacsony gravitáció</translation>
    </message>
    <message>
        <source>Laser Sight</source>
        <translation>Lézeres mutató</translation>
    </message>
    <message>
        <source>Invulnerable</source>
        <translation>Sérthetetlenség</translation>
    </message>
    <message>
        <source>Add Mines</source>
        <translation type="obsolete">Aknák hozzáadása</translation>
    </message>
    <message>
        <source>Random Order</source>
        <translation>Véletlen sorrend</translation>
    </message>
    <message>
        <source>King</source>
        <translation>Király</translation>
    </message>
    <message>
        <source>Place Hedgehogs</source>
        <translation>Sünik elhelyezése</translation>
    </message>
    <message>
        <source>Clan Shares Ammo</source>
        <translation>Közös lőszerek</translation>
    </message>
    <message>
        <source>Disable Girders</source>
        <translation>Hidak tiltása</translation>
    </message>
    <message>
        <source>Disable Land Objects</source>
        <translation>Tereptárgyak tiltása</translation>
    </message>
    <message>
        <source>Reset Health</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AI Survival Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unlimited Attacks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Weapons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Per Hedgehog Ammo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tag Team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Bottom Border</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation>fel</translation>
    </message>
    <message>
        <source>left</source>
        <translation>balra</translation>
    </message>
    <message>
        <source>right</source>
        <translation>jobbra</translation>
    </message>
    <message>
        <source>down</source>
        <translation>le</translation>
    </message>
    <message>
        <source>attack</source>
        <translation>támadás</translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation>pontos célzás</translation>
    </message>
    <message>
        <source>put</source>
        <translation>elhelyezés</translation>
    </message>
    <message>
        <source>switch</source>
        <translation>váltás</translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation>süni megtalálása</translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation>lőszer menü</translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation>slot 1</translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation>slot 2</translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation>slot 3</translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation>slot 4</translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation>slot 5</translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation>slot 6</translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation>slot 7</translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation>slot 8</translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation>slot 9</translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation>1 mp időzítés</translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation>2 mp időzítés</translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation>3 mp időzítés</translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation>4 mp időzítés</translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation>5 mp időzítés</translation>
    </message>
    <message>
        <source>chat</source>
        <translation>chat</translation>
    </message>
    <message>
        <source>chat history</source>
        <translation>chat history</translation>
    </message>
    <message>
        <source>pause</source>
        <translation>szünet</translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation>megerősítés</translation>
    </message>
    <message>
        <source>volume down</source>
        <translation>hangerő csökkentése</translation>
    </message>
    <message>
        <source>volume up</source>
        <translation>hangerő növelése</translation>
    </message>
    <message>
        <source>change mode</source>
        <translation>mód váltása</translation>
    </message>
    <message>
        <source>capture</source>
        <translation>elfogás</translation>
    </message>
    <message>
        <source>hedgehogs
info</source>
        <translation>süni
info</translation>
    </message>
    <message>
        <source>quit</source>
        <translation>kilépés</translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation>ráközelítés</translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation>távolodás</translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation>zoom visszaállítása</translation>
    </message>
    <message>
        <source>long jump</source>
        <translation>hosszú ugrás</translation>
    </message>
    <message>
        <source>high jump</source>
        <translation>magasugrás</translation>
    </message>
    <message>
        <source>slot 10</source>
        <translation type="unfinished">slot 10</translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Basic controls</source>
        <translation>Alap irányítás</translation>
    </message>
    <message>
        <source>Weapon controls</source>
        <translation>Fegyverek kezelése</translation>
    </message>
    <message>
        <source>Camera and cursor controls</source>
        <translation>Kamera és kurzor irányítása</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Egyéb</translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Move your hogs and aim:</source>
        <translation>Süni mozgatása és célzás:</translation>
    </message>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation>Gödrök és akadályok leküzdése ugrással:</translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation>Kijelölt fegyver vagy eszköz aktiválása:</translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation>A kurzor alatti fegyver vagy célterület kiválasztása:</translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation>Aktív sün kiválasztása (amennyiben lehetséges):</translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation>Fegyver vagy eszköz kijelölése:</translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation>Időzítő beállítása bombákon és időzíthető fegyvereken:</translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation>Kamera mozgatása az aktív sünire:</translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation>Kurzor vagy kamera mozgatása egér nélkül:</translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation>Kamera ráközelítsének módosítása:</translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation>Beszélgetés a csapattal vagy minden résztvevővel:</translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation>Szünet, folytatás vagy játék elhagyása:</translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation>Játék hangerejének módosítása játék közben:</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation>Teljes képernyős mód:</translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation>Képlopás:</translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation>Sünik feletti címkék beállítása:</translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation>Tengely</translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation>(Fel)</translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation>(Le)</translation>
    </message>
    <message>
        <source>Hat</source>
        <translation>Kalap</translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation>(Balra)</translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation>(Jobbra)</translation>
    </message>
    <message>
        <source>Button</source>
        <translation>Gomb</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation>Billentyűzet</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation>Egér: Bal gomb</translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation>Egér: Középső gomb</translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation>Egér: Jobb gomb</translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation>Egér: Görgetés felfelé</translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation>Egér: Görgetés lefelé</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>Backspace</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Szünet</translation>
    </message>
    <message>
        <source>Escape</source>
        <translation>Escape</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Szóköz</translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation>Numpad 0</translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation>Numpad 1</translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation>Numpad 2</translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation>Numpad 3</translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation>Numpad 4</translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation>Numpad 5</translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation>Numpad 6</translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation>Numpad 7</translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation>Numpad 8</translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation>Numpad 9</translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation>Numpad .</translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation>Numpad /</translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation>Numpad *</translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation>Numpad -</translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation>Numpad +</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Equals</source>
        <translation>Egyenlő</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Fel</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Le</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Jobbra</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Balra</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Insert</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Page up</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Page Down</translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation>Num lock</translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation>Caps lock</translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation>Scroll lock</translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation>Jobb oldali Shift</translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation>Bal oldali Shift</translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation>Jobb oldali Ctrl</translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation>Bal oldali Ctrl</translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation>Jobb oldali Alt</translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation>Bal oldali Alt</translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation>Jobb oldali Meta</translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation>Bal oldali Meta</translation>
    </message>
    <message>
        <source>A button</source>
        <translation>A gomb</translation>
    </message>
    <message>
        <source>B button</source>
        <translation>B gomb</translation>
    </message>
    <message>
        <source>X button</source>
        <translation>X gomb</translation>
    </message>
    <message>
        <source>Y button</source>
        <translation>Y gomb</translation>
    </message>
    <message>
        <source>LB button</source>
        <translation>LB gomb</translation>
    </message>
    <message>
        <source>RB button</source>
        <translation>RB gomb</translation>
    </message>
    <message>
        <source>Back button</source>
        <translation>Vissza gomb</translation>
    </message>
    <message>
        <source>Start button</source>
        <translation>Start gomb</translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation>Bal rúd</translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation>Jobb rúd</translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation>Bal rúd (Jobbra)</translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation>Bal rúd (Balra)</translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation>Bal rúd (Le)</translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation>Bal rúd (Fel)</translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation>Bal trigger</translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation>Jobb trigger</translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation>Job rúd (Le)</translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation>Jobb rúd (Fel)</translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation>Jobb rúd (Jobbra)</translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation>Jobb rúd (Balra)</translation>
    </message>
    <message>
        <source>DPad</source>
        <translation>DPad</translation>
    </message>
</context>
</TS>
